@@ -2,7 +2,6 @@ from .. import mongo
 
 from .base_document import BaseDocument
 
-
 class Config(mongo.Document):
     min_version_code = mongo.IntField(unique=True, required=True)
     require_update = mongo.BooleanField(default=False)
@@ -10,9 +9,8 @@ class Config(mongo.Document):
     properties = mongo.DictField(default=dict())
 
     meta = {
-        'collection': 'configs',
-        'strict': False
+        'collection' : 'configs'
     }
 
     def __repr__(self):
-        return "<Config '{}'>".format(self.properties)
+           return "<Config '{}'>".format(self.properties)
\ No newline at end of file
