@@ -39,7 +39,7 @@ class RecipeList(Resource):
         recipe.owner = user_info.id
 
         try:
-            recipe.save()
+            recipe.save(force_insert=True)
         except NotUniqueError as nue:
             raise DuplicateEntry(
                 description="duplicate entry found for a recipe", details=nue.args or [])
@@ -72,7 +72,7 @@ class RecipeInstance(Resource):
 
         result = put_document(Recipe, new_recipe, old_recipe)
 
-        if(result['n'] != 1):
+        if(result.modified_count != 1):
             raise BadRequest(description='no matching recipe with id: {}'.format(recipe_id))
         
         old_recipe.reload()
@@ -86,7 +86,7 @@ class RecipeInstance(Resource):
 
         result = patch_document(Recipe, new_recipe, old_recipe)
 
-        if(result['n'] != 1):
+        if(result.modified_count != 1):
             raise BadRequest(description='no matching recipe with id: {}'.format(recipe_id))
         
         old_recipe.reload()
